@@ -174,7 +174,7 @@ sub _dump
 		my $v = "$rval";
 
 		my $mod = "";
-		if ($v =~ /^\(\?([msix-]+):([\x00-\xFF]*)\)\z/) {
+		if ($v =~ /^\(\?\^?([msix-]*):([\x00-\xFF]*)\)\z/) {
 		    $mod = $1;
 		    $v = $2;
 		    $mod =~ s/-.*//;
@@ -504,10 +504,6 @@ __END__
 
 Data::Dump::PHP - Pretty printing of data structures as PHP code
 
-=head1 VERSION
-
-version 0.04
-
 =head1 SYNOPSIS
 
  use Data::Dump::PHP qw(dump_php ddx_php);
@@ -651,4 +647,4 @@ The C<Data::Dump::PHP> module is written by Steven Haryanto
 This library is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
 
-=cut
\ No newline at end of file
+=cut
